@@ -1,19 +1,14 @@
 from .Transformer import Transformer
-from .ALBERT import ALBERT
-from .BERT import BERT
+from .Asym import Asym
 from .BoW import BoW
 from .CNN import CNN
-from .CamemBERT import CamemBERT
 from .Dense import Dense
-from .DistilBERT import DistilBERT
+from .Dropout import Dropout
+from .LayerNorm import LayerNorm
 from .LSTM import LSTM
 from .Normalize import Normalize
 from .Pooling import Pooling
-from .RoBERTa import RoBERTa
-from .T5 import T5
-from .WKPooling import WKPooling
 from .WeightedLayerPooling import WeightedLayerPooling
 from .WordEmbeddings import WordEmbeddings
 from .WordWeights import WordWeights
-from .XLMRoBERTa import XLMRoBERTa
-from .XLNet import XLNet
+from .CLIPModel import CLIPModel
